@@ -11,6 +11,8 @@ class DBConnection(object):
     * ``toto.redisconnection.RedisConnection``
   '''
 
+  _session_cache = None
+
   def create_account(self, user_id, password, additional_values={}, **values):
     '''Create an account for the given ``user_id`` and ``password``. Optionally set additional account
       values by passing them as keyword arguments (the ``additional_values`` parameter is deprecated).
@@ -60,6 +62,36 @@ class DBConnection(object):
     '''
     raise NotImplementedError()
 
+  def set_session_cache(self, session_cache):
+    '''Optionally set an instance of ``TotoSessionCache`` that will be used to store sessions separately from
+    this database.
+    '''
+    self._session_cache = session_cache
+
+  def _load_session_data(self, session_id):
+    '''Called by ``DBConnection.retrieve_session``. Will attempt to load data from an associated ``TotoSessionCache``.
+    If no ``TotoSessionCache`` is associated with the current instance, the result of ``self._load_uncached_data(session_id)``
+    is returned.
+    '''
+    if self._session_cache:
+      return self._session_cache.load_session(session_id)
+    return self._load_uncached_data(session_id)
+
+  def _load_uncached_data(self, session_id):
+    '''Load a session data ``dict`` from the local database. Called by default and if no ``TotoSessionCache`` has been
+    associated with the current instance of ``DBConnection``. 
+    '''
+    raise NotImplementedError()
+
+  def _cache_session_data(self, session_data):
+    '''Called by ``DBConnection.create_session`` and by ``DBConnection.retrieve_session`` if there is a change in ``TotoSession.expires``.
+    Returns ``True`` if the session has been written to an associated ``TotoSessionCache``, ``False`` otherwise.
+    '''
+    if self._session_cache:
+      self._session_cache.store_session(session_data)
+      return True
+    return False
+
 from tornado.options import define, options
 
 define("database", metavar='mysql|mongodb|redis|postgres|none', default="none", help="the database driver to use")
